//Demo for Rotary Angle Sensor by Catalex
//Hardware: A Rotary Angle Sensor and a LED
//Board: Carduino or Arduino UNO R3... 
//IDE:   Arduino-1.0
//Function: Rotate the potentiometer to adjust the LED brightness.
//Store: catalex.taobao.com

/*********************************************************************/
/*macro definitions of Rotary angle sensor and LED pin*/
#define ROTARY_ANGLE_SENSOR A0
#define LED 3//the SIG pin on the LED module is connected with D3 of Arduino/Catduino

#define ADC_REF 5//reference voltage of ADC is 5v
#define VCC     5    //the default value of VCC of the control interface is 5v
#define FULL_ANGLE 280//full value of the rotary angle is 280 degrees

void setup() 
{
	Serial.begin(9600);
	pinsInit();
}

void loop() 
{
	int degrees;
	degrees = getDegree();
	Serial.println("The angle between the mark and the starting position:");
	Serial.println(degrees);
	
	int brightness;
	/*The degrees is 0~280, should be converted to be 0~255 to control the*/
	/*brightness of LED */
	brightness = map(degrees, 0, FULL_ANGLE, 0, 255); 
	controlBrightness(brightness);
	
	delay(500);
}
void pinsInit()
{
	pinMode(ROTARY_ANGLE_SENSOR, INPUT);
	pinMode(LED,OUTPUT);
}

/*PWM control brightness                               */
/*If brightness is 0,the LED is off.                    */
/*The Greater the brightness, the brighter the LED.*/
/*The range of brightness is 0~255                      */
void controlBrightness(int brightness)
{
	analogWrite(LED,brightness);
}
/********************************************************************************/
/*Function: Get the angle between the mark on the potentiometer cap and the starting position	*/
/*Parameter:-void                                                                                                          */
/*Return:     -int,the range of degrees is 0~280                                                                 */
int getDegree()
{
	int sensor_value = analogRead(ROTARY_ANGLE_SENSOR);
	float voltage;
	voltage = (float)sensor_value*ADC_REF/1023;
	float degrees = (voltage*FULL_ANGLE)/VCC;
	return degrees;
}

